@@ -23,7 +23,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 import java.util.function.Predicate;
-
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
@@ -35,8 +34,6 @@ import com.google.gwt.view.client.Range;
 import org.dashbuilder.dataset.DataSet;
 import org.dashbuilder.dataset.DataSetLookup;
 import org.dashbuilder.dataset.DataSetLookupFactory;
-import org.dashbuilder.dataset.filter.ColumnFilter;
-import org.dashbuilder.dataset.filter.DataSetFilter;
 import org.dashbuilder.dataset.sort.SortOrder;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
@@ -50,8 +47,9 @@ import org.jbpm.workbench.common.client.util.DateUtils;
 import org.jbpm.workbench.df.client.filter.FilterSettings;
 import org.jbpm.workbench.df.client.filter.FilterSettingsBuilderHelper;
 import org.jbpm.workbench.df.client.list.DataSetQueryHelper;
-import org.jbpm.workbench.es.client.editors.jobdetails.JobDetailsPopup;
-import org.jbpm.workbench.es.client.editors.quicknewjob.QuickNewJobPopup;
+import org.jbpm.workbench.es.client.editors.events.JobSelectedEvent;
+import org.jbpm.workbench.es.client.editors.quicknewjob.NewJobPresenter;
+
 import org.jbpm.workbench.es.client.i18n.Constants;
 import org.jbpm.workbench.es.model.RequestSummary;
 import org.jbpm.workbench.es.model.events.RequestChangedEvent;
@@ -60,9 +58,12 @@ import org.jbpm.workbench.es.util.RequestStatus;
 import org.uberfire.client.annotations.WorkbenchMenu;
 import org.uberfire.client.annotations.WorkbenchPartTitle;
 import org.uberfire.client.annotations.WorkbenchScreen;
+import org.uberfire.client.mvp.PlaceManager;
+import org.uberfire.client.mvp.PlaceStatus;
 import org.uberfire.client.workbench.widgets.common.ErrorPopupPresenter;
 import org.uberfire.ext.widgets.common.client.menu.RefreshMenuBuilder;
 import org.uberfire.mvp.Command;
+import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.workbench.model.menu.MenuFactory;
 import org.uberfire.workbench.model.menu.Menus;
 
@@ -71,27 +72,31 @@ import static org.jbpm.workbench.common.client.util.DataSetUtils.*;
 import static org.jbpm.workbench.es.model.RequestDataSetConstants.*;
 
 @Dependent
-@WorkbenchScreen(identifier = RequestListPresenter.SCREEN_ID)
+@WorkbenchScreen(identifier = PerspectiveIds.JOB_LIST_SCREEN)
 public class RequestListPresenter extends AbstractMultiGridPresenter<RequestSummary, RequestListPresenter.RequestListView> {
 
-    public static final String SCREEN_ID = "Requests List";
-
     private Constants constants = Constants.INSTANCE;
 
+    private NewJobPresenter newJobPresenter;
+
+    private Command newJobCommand;
+
     @Inject
     private Caller<ExecutorService> executorServices;
 
     @Inject
     private Event<RequestChangedEvent> requestChangedEvent;
 
-    @Inject
-    private QuickNewJobPopup quickNewJobPopup;
-
     @Inject
     private ErrorPopupPresenter errorPopup;
 
     @Inject
-    private JobDetailsPopup jobDetailsPopup;
+    private Event<JobSelectedEvent> jobSelectedEvent;
+
+    @Inject
+    protected void setNewJobPresenter(NewJobPresenter newJobPresenter) {
+        this.newJobPresenter = newJobPresenter;
+    }
 
     public RequestListPresenter() {
         super();
@@ -100,17 +105,25 @@ public class RequestListPresenter extends AbstractMultiGridPresenter<RequestSumm
     public RequestListPresenter(RequestListViewImpl view,
                                 Caller<ExecutorService> executorServices,
                                 DataSetQueryHelper dataSetQueryHelper,
-                                Event<RequestChangedEvent> requestChangedEvent
+                                Event<RequestChangedEvent> requestChangedEvent,
+                                Event<JobSelectedEvent> jobSelectedEvent,
+                                PlaceManager placeManager
     ) {
         this.view = view;
         this.executorServices = executorServices;
         this.dataSetQueryHelper = dataSetQueryHelper;
         this.requestChangedEvent = requestChangedEvent;
+        this.jobSelectedEvent = jobSelectedEvent;
+        this.placeManager = placeManager;
     }
 
     @WorkbenchPartTitle
     public String getTitle() {
-        return constants.RequestsListTitle();
+        return constants.Jobs();
+    }
+
+    public Command getNewJobCommand() {
+        return newJobCommand;
     }
 
     @Override
@@ -129,17 +142,6 @@ public class RequestListPresenter extends AbstractMultiGridPresenter<RequestSumm
                     dataSetQueryHelper.setLastSortOrder(SortOrder.ASCENDING);
                 }
 
-                final List<ColumnFilter> filters = getColumnFilters(textSearchStr);
-                if (filters.isEmpty() == false) {
-                    if (currentTableSettings.getDataSetLookup().getFirstFilterOp() != null) {
-                        currentTableSettings.getDataSetLookup().getFirstFilterOp().addFilterColumn(OR(filters));
-                    } else {
-                        final DataSetFilter filter = new DataSetFilter();
-                        filter.addFilterColumn(OR(filters));
-                        currentTableSettings.getDataSetLookup().addOperation(filter);
-                    }
-                }
-
                 dataSetQueryHelper.setDataSetHandler(currentTableSettings);
                 dataSetQueryHelper.lookupDataSet(visibleRange.getStart(),
                                                  new AbstractDataSetReadyCallback(errorPopup,
@@ -182,9 +184,9 @@ public class RequestListPresenter extends AbstractMultiGridPresenter<RequestSumm
                 getColumnDateValue(dataSet,
                                    COLUMN_TIMESTAMP,
                                    index),
-                getColumnStringValue(dataSet,
-                                     COLUMN_STATUS,
-                                     index),
+                RequestStatus.valueOf(getColumnStringValue(dataSet,
+                                                           COLUMN_STATUS,
+                                                           index)),
                 getColumnStringValue(dataSet,
                                      COLUMN_COMMANDNAME,
                                      index),
@@ -208,63 +210,55 @@ public class RequestListPresenter extends AbstractMultiGridPresenter<RequestSumm
                                    index),
                 getColumnStringValue(dataSet,
                                      COLUMN_PROCESS_INSTANCE_DESCRIPTION,
+                                     index),
+                getColumnStringValue(dataSet,
+                                     COLUMN_JOB_DEPLOYMENT_ID,
                                      index)
         );
     }
 
-    protected List<ColumnFilter> getColumnFilters(final String searchString) {
-        final List<ColumnFilter> filters = new ArrayList<ColumnFilter>();
-        if (searchString != null && searchString.trim().length() > 0) {
-            filters.add(likeTo(COLUMN_COMMANDNAME,
-                               "%" + searchString.toLowerCase() + "%",
-                               false));
-            filters.add(likeTo(COLUMN_MESSAGE,
-                               "%" + searchString.toLowerCase() + "%",
-                               false));
-            filters.add(likeTo(COLUMN_BUSINESSKEY,
-                               "%" + searchString.toLowerCase() + "%",
-                               false));
-        }
-        return filters;
-    }
-
-    public void cancelRequest(final Long requestId) {
+    public void cancelRequest(final String deploymentId,
+                              final Long requestId) {
         executorServices.call(new RemoteCallback<Void>() {
             @Override
             public void callback(Void nothing) {
-                view.displayNotification(constants.RequestCancelled(requestId));
+                view.displayNotification(constants.RequestCanceled(requestId));
                 requestChangedEvent.fire(new RequestChangedEvent(requestId));
             }
         }).cancelRequest(getSelectedServerTemplate(),
+                         deploymentId,
                          requestId);
     }
 
-    public void requeueRequest(final Long requestId) {
+    public void requeueRequest(final String deploymentId,
+                               final Long requestId) {
         executorServices.call(new RemoteCallback<Void>() {
             @Override
             public void callback(Void nothing) {
-                view.displayNotification(constants.RequestCancelled(requestId));
+                view.displayNotification(constants.RequestRequeued(requestId));
                 requestChangedEvent.fire(new RequestChangedEvent(requestId));
             }
         }).requeueRequest(getSelectedServerTemplate(),
+                          deploymentId,
                           requestId);
     }
 
     @WorkbenchMenu
     public Menus getMenus() {
+        newJobCommand = new Command() {
+                            @Override
+                            public void execute() {
+                                final String selectedServerTemplate = getSelectedServerTemplate();
+                                if (selectedServerTemplate == null || selectedServerTemplate.trim().isEmpty()) {
+                                    view.displayNotification(constants.SelectServerTemplate());
+                                } else {
+                                    newJobPresenter.openNewJobDialog(selectedServerTemplate);
+                                }
+                            }
+        };
         return MenuFactory
                 .newTopLevelMenu(constants.New_Job())
-                .respondsWith(new Command() {
-                    @Override
-                    public void execute() {
-                        final String selectedServerTemplate = getSelectedServerTemplate();
-                        if (selectedServerTemplate == null || selectedServerTemplate.trim().isEmpty()) {
-                            view.displayNotification(constants.SelectServerTemplate());
-                        } else {
-                            quickNewJobPopup.show(selectedServerTemplate);
-                        }
-                    }
-                })
+                .respondsWith(newJobCommand)
                 .endMenu()
                 .newTopLevelCustomMenu(serverTemplateSelectorMenuBuilder)
                 .endMenu()
@@ -274,9 +268,24 @@ public class RequestListPresenter extends AbstractMultiGridPresenter<RequestSumm
                 .build();
     }
 
-    public void showJobDetails(final RequestSummary job) {
-        jobDetailsPopup.show(getSelectedServerTemplate(),
-                             String.valueOf(job.getJobId()));
+    public void selectJob(final RequestSummary job,
+                          final Boolean close) {
+
+        if (job.getStatus() != null) {
+            PlaceStatus status = placeManager.getStatus(new DefaultPlaceRequest(PerspectiveIds.JOB_DETAILS_SCREEN));
+            if (status == PlaceStatus.CLOSE) {
+                placeManager.goTo(PerspectiveIds.JOB_DETAILS_SCREEN);
+                jobSelectedEvent.fire(new JobSelectedEvent(getSelectedServerTemplate(),
+                                                           job.getDeploymentId(),
+                                                           job.getJobId()));
+            } else if (status == PlaceStatus.OPEN && !close) {
+                jobSelectedEvent.fire(new JobSelectedEvent(getSelectedServerTemplate(),
+                                                           job.getDeploymentId(),
+                                                           job.getJobId()));
+            } else if (status == PlaceStatus.OPEN && close) {
+                placeManager.closePlace(PerspectiveIds.JOB_DETAILS_SCREEN);
+            }
+        }
     }
 
     public void requestCreated(@Observes RequestChangedEvent event) {
@@ -313,7 +322,7 @@ public class RequestListPresenter extends AbstractMultiGridPresenter<RequestSumm
                                                                   false))
         );
 
-        view.addTextFilter(constants.Process_Description(),
+        view.addTextFilter(constants.Process_Instance_Description(),
                            constants.FilterByProcessDescription(),
                            v -> addAdvancedSearchFilter(likeTo(COLUMN_PROCESS_INSTANCE_DESCRIPTION,
                                                                v,
@@ -325,7 +334,7 @@ public class RequestListPresenter extends AbstractMultiGridPresenter<RequestSumm
 
         final Map<String, String> status = new HashMap<>();
         status.put(RequestStatus.CANCELLED.name(),
-                   constants.Cancelled());
+                   constants.Canceled());
         status.put(RequestStatus.DONE.name(),
                    constants.Completed());
         status.put(RequestStatus.ERROR.name(),
@@ -365,6 +374,7 @@ public class RequestListPresenter extends AbstractMultiGridPresenter<RequestSumm
 
         view.addDateRangeFilter(constants.Due_On(),
                                 constants.Due_On_Placeholder(),
+                                false,
                                 v -> addAdvancedSearchFilter(between(COLUMN_TIMESTAMP,
                                                                      v.getStartDate(),
                                                                      v.getEndDate())),
@@ -460,7 +470,9 @@ public class RequestListPresenter extends AbstractMultiGridPresenter<RequestSumm
         builder.setColumn(COLUMN_PROCESS_INSTANCE_ID,
                           constants.Process_Instance_Id());
         builder.setColumn(COLUMN_PROCESS_INSTANCE_DESCRIPTION,
-                          constants.Process_Description());
+                          constants.Process_Instance_Description());
+        builder.setColumn(COLUMN_JOB_DEPLOYMENT_ID,
+                          constants.DeploymentId());
 
         builder.filterOn(true,
                          true,
@@ -500,21 +512,10 @@ public class RequestListPresenter extends AbstractMultiGridPresenter<RequestSumm
         return createStatusSettings(RequestStatus.DONE);
     }
 
-    public FilterSettings createCancelledTabSettings() {
+    public FilterSettings createCanceledTabSettings() {
         return createStatusSettings(RequestStatus.CANCELLED);
     }
 
-    public Predicate<RequestSummary> getDetailsActionCondition() {
-        return getActionConditionFromStatusList(new RequestStatus[]{
-                RequestStatus.QUEUED,
-                RequestStatus.DONE,
-                RequestStatus.CANCELLED,
-                RequestStatus.ERROR,
-                RequestStatus.RETRYING,
-                RequestStatus.RUNNING
-        });
-    }
-
     public Predicate<RequestSummary> getCancelActionCondition() {
         return getActionConditionFromStatusList(new RequestStatus[]{
                 RequestStatus.QUEUED,
@@ -536,7 +537,7 @@ public class RequestListPresenter extends AbstractMultiGridPresenter<RequestSumm
 
     private Predicate<RequestSummary> getActionConditionFromStatusList(RequestStatus[] statusList) {
         return value -> Arrays.stream(statusList).anyMatch(
-                s -> s.name().equals(value.getStatus()));
+                s -> s.equals(value.getStatus()));
     }
 
     public interface RequestListView extends MultiGridView<RequestSummary, RequestListPresenter> {
