@@ -59,7 +59,6 @@ import org.jbpm.workbench.df.client.filter.FilterSettingsBuilderHelper;
 import org.jbpm.workbench.df.client.list.DataSetQueryHelper;
 import org.jbpm.workbench.ht.client.resources.i18n.Constants;
 import org.jbpm.workbench.ht.model.TaskSummary;
-import org.jbpm.workbench.ht.model.events.NewTaskEvent;
 import org.jbpm.workbench.ht.model.events.TaskCompletedEvent;
 import org.jbpm.workbench.ht.model.events.TaskRefreshedEvent;
 import org.jbpm.workbench.ht.model.events.TaskSelectionEvent;
@@ -103,16 +102,6 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
                     dataSetQueryHelper.setLastSortOrder(SortOrder.ASCENDING);
                 }
 
-                final List<ColumnFilter> filters = getColumnFilters(textSearchStr);
-                if (filters.isEmpty() == false) {
-                    if (currentTableSettings.getDataSetLookup().getFirstFilterOp() != null) {
-                        currentTableSettings.getDataSetLookup().getFirstFilterOp().addFilterColumn(OR(filters));
-                    } else {
-                        final DataSetFilter filter = new DataSetFilter();
-                        filter.addFilterColumn(OR(filters));
-                        currentTableSettings.getDataSetLookup().addOperation(filter);
-                    }
-                }
                 dataSetQueryHelper.setDataSetHandler(currentTableSettings);
                 dataSetQueryHelper.lookupDataSet(visibleRange.getStart(),
                                                  createDataSetTaskCallback(visibleRange.getStart(),
@@ -123,28 +112,6 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
         }
     }
 
-    protected List<ColumnFilter> getColumnFilters(final String searchString) {
-        final List<ColumnFilter> filters = new ArrayList<ColumnFilter>();
-        if (searchString != null && searchString.trim().length() > 0) {
-            try {
-                final Long taskId = Long.valueOf(searchString.trim());
-                filters.add(equalsTo(COLUMN_TASK_ID,
-                                     taskId));
-            } catch (NumberFormatException ex) {
-                filters.add(likeTo(COLUMN_NAME,
-                                   "%" + searchString.toLowerCase() + "%",
-                                   false));
-                filters.add(likeTo(COLUMN_DESCRIPTION,
-                                   "%" + searchString.toLowerCase() + "%",
-                                   false));
-                filters.add(likeTo(COLUMN_PROCESS_ID,
-                                   "%" + searchString.toLowerCase() + "%",
-                                   false));
-            }
-        }
-        return filters;
-    }
-
     /**
      * Generates a dataset filter depending of the user roles and the kind of dataset.
      * <br>In case of the adminDataset (isAdminDateset=true), retrieve the tasks that are accessible for the user logged
@@ -339,10 +306,8 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
                 }).releaseTask(getSelectedServerTemplate(),
                                task.getDeploymentId(),
                                task.getId());
-        taskSelected.fire(new TaskSelectionEvent(getSelectedServerTemplate(),
-                                                 task.getDeploymentId(),
-                                                 task.getId(),
-                                                 task.getName()));
+        fireTaskSelectionEvent(task,
+                               false);
     }
 
     public void claimTask(final TaskSummary task) {
@@ -357,10 +322,8 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
         ).claimTask(getSelectedServerTemplate(),
                     task.getDeploymentId(),
                     task.getId());
-        taskSelected.fire(new TaskSelectionEvent(getSelectedServerTemplate(),
-                                                 task.getDeploymentId(),
-                                                 task.getId(),
-                                                 task.getName()));
+        fireTaskSelectionEvent(task,
+                               false);
     }
 
     public void resumeTask(final TaskSummary task) {
@@ -375,10 +338,8 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
         ).resumeTask(getSelectedServerTemplate(),
                      task.getDeploymentId(),
                      task.getId());
-        taskSelected.fire(new TaskSelectionEvent(getSelectedServerTemplate(),
-                                                 task.getDeploymentId(),
-                                                 task.getId(),
-                                                 task.getName()));
+        fireTaskSelectionEvent(task,
+                               false);
     }
 
     public void suspendTask(final TaskSummary task) {
@@ -393,10 +354,8 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
         ).suspendTask(getSelectedServerTemplate(),
                       task.getDeploymentId(),
                       task.getId());
-        taskSelected.fire(new TaskSelectionEvent(getSelectedServerTemplate(),
-                                                 task.getDeploymentId(),
-                                                 task.getId(),
-                                                 task.getName()));
+        fireTaskSelectionEvent(task,
+                               false);
     }
 
     public Menus getMenus() { //To be used by subclass methods annotated with @WorkbenchMenu
@@ -410,49 +369,39 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
 
     public void selectTask(final TaskSummary summary,
                            final Boolean close) {
-        final DefaultPlaceRequest defaultPlaceRequest = new DefaultPlaceRequest("Task Details Multi");
-        final PlaceStatus status = placeManager.getStatus(defaultPlaceRequest);
+        PlaceStatus status = placeManager.getStatus(new DefaultPlaceRequest(PerspectiveIds.TASK_DETAILS_SCREEN));
         boolean logOnly = false;
-        if (summary.getStatus().equals(TASK_STATUS_COMPLETED) && summary.isLogOnly()) {
+        if (TASK_STATUS_COMPLETED.equals(summary.getStatus()) ||
+                TASK_STATUS_EXITED.equals(summary.getStatus())) {
             logOnly = true;
         }
         if (status == PlaceStatus.CLOSE) {
-            placeManager.goTo(defaultPlaceRequest);
-            taskSelected.fire(new TaskSelectionEvent(getSelectedServerTemplate(),
-                                                     summary.getDeploymentId(),
-                                                     summary.getId(),
-                                                     summary.getName(),
-                                                     summary.isForAdmin(),
-                                                     logOnly));
+            placeManager.goTo(PerspectiveIds.TASK_DETAILS_SCREEN);
+            fireTaskSelectionEvent(summary,
+                                   logOnly);
         } else if (status == PlaceStatus.OPEN && !close) {
-            taskSelected.fire(new TaskSelectionEvent(getSelectedServerTemplate(),
-                                                     summary.getDeploymentId(),
-                                                     summary.getId(),
-                                                     summary.getName(),
-                                                     summary.isForAdmin(),
-                                                     logOnly));
+            fireTaskSelectionEvent(summary,
+                                   logOnly);
         } else if (status == PlaceStatus.OPEN && close) {
-            placeManager.closePlace("Task Details Multi");
+            placeManager.closePlace(PerspectiveIds.TASK_DETAILS_SCREEN);
         }
     }
 
-    public void refreshNewTask(@Observes NewTaskEvent newTask) {
-        refreshGrid();
-        PlaceStatus status = placeManager.getStatus(new DefaultPlaceRequest("Task Details Multi"));
-        if (status == PlaceStatus.OPEN) {
-            taskSelected.fire(new TaskSelectionEvent(getSelectedServerTemplate(),
-                                                     null,
-                                                     newTask.getNewTaskId(),
-                                                     newTask.getNewTaskName()));
-        } else {
-            placeManager.goTo("Task Details Multi");
-            taskSelected.fire(new TaskSelectionEvent(getSelectedServerTemplate(),
-                                                     null,
-                                                     newTask.getNewTaskId(),
-                                                     newTask.getNewTaskName()));
-        }
-
-        view.setSelectedTask(TaskSummary.builder().id(newTask.getNewTaskId()).name(newTask.getNewTaskName()).build());
+    private void fireTaskSelectionEvent(TaskSummary summary,
+                                        boolean logOnly) {
+        taskSelected.fire(new TaskSelectionEvent(getSelectedServerTemplate(),
+                                                 summary.getDeploymentId(),
+                                                 summary.getId(),
+                                                 summary.getName(),
+                                                 summary.isForAdmin(),
+                                                 logOnly,
+                                                 summary.getDescription(),
+                                                 summary.getExpirationTime(),
+                                                 summary.getStatus(),
+                                                 summary.getActualOwner(),
+                                                 summary.getPriority(),
+                                                 summary.getProcessInstanceId(),
+                                                 summary.getProcessId()));
     }
 
     public void onTaskRefreshedEvent(@Observes TaskRefreshedEvent event) {
@@ -536,6 +485,7 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
 
         view.addDateRangeFilter(constants.Created_On(),
                                 constants.Created_On_Placeholder(),
+                                true,
                                 v -> addAdvancedSearchFilter(between(COLUMN_CREATED_ON,
                                                                      v.getStartDate(),
                                                                      v.getEndDate())),
@@ -604,7 +554,7 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
                 .sort(COLUMN_PROCESS_ID,
                       SortOrder.ASCENDING)
                 .buildLookup();
-        view.addDataSetSelectFilter(constants.Process_Name(),
+        view.addDataSetSelectFilter(constants.Process_Definition_Id(),
                                     AbstractMultiGridView.TAB_SEARCH,
                                     dataSetLookup,
                                     COLUMN_PROCESS_ID,
@@ -658,7 +608,7 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
         builder.setColumn(COLUMN_PRIORITY,
                           constants.Priority());
         builder.setColumn(COLUMN_PROCESS_ID,
-                          constants.Process_Id());
+                          constants.Process_Definition_Id());
         builder.setColumn(COLUMN_PROCESS_INSTANCE_ID,
                           constants.Process_Instance_Id());
         builder.setColumn(COLUMN_PROCESS_SESSION_ID,
