@@ -26,7 +26,6 @@ import java.util.function.Predicate;
 import javax.enterprise.event.Event;
 
 import com.google.gwt.view.client.Range;
-import org.apache.commons.lang3.RandomStringUtils;
 import org.dashbuilder.common.client.error.ClientRuntimeError;
 import org.dashbuilder.dataset.DataSet;
 import org.dashbuilder.dataset.DataSetLookup;
@@ -40,7 +39,7 @@ import org.dashbuilder.dataset.filter.LogicalExprType;
 import org.dashbuilder.dataset.sort.SortOrder;
 import org.jboss.errai.security.shared.api.Group;
 import org.jboss.errai.security.shared.api.identity.User;
-import org.jbpm.workbench.common.client.events.SearchEvent;
+import org.jbpm.workbench.common.client.PerspectiveIds;
 import org.jbpm.workbench.common.client.list.ExtendedPagedTable;
 import org.jbpm.workbench.common.client.menu.ServerTemplateSelectorMenuBuilder;
 import org.jbpm.workbench.common.client.util.TaskUtils;
@@ -57,8 +56,11 @@ import org.mockito.Mock;
 import org.mockito.Spy;
 import org.mockito.invocation.InvocationOnMock;
 import org.mockito.stubbing.Answer;
+import org.uberfire.client.mvp.PlaceManager;
+import org.uberfire.client.mvp.PlaceStatus;
 import org.uberfire.mocks.CallerMock;
 import org.uberfire.mocks.EventSourceMock;
+import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.workbench.model.menu.Menus;
 
 import static org.dashbuilder.dataset.filter.FilterFactory.equalsTo;
@@ -69,7 +71,6 @@ import static org.jbpm.workbench.ht.model.TaskDataSetConstants.*;
 import static org.junit.Assert.*;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyInt;
-import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.*;
 
@@ -107,6 +108,9 @@ public abstract class AbstractTaskListPresenterTest {
     @Mock
     private DataSet dataSetTaskVarMock;
 
+    @Mock
+    private PlaceManager placeManager;
+
     @Spy
     private FilterSettings filterSettings;
 
@@ -377,83 +381,6 @@ public abstract class AbstractTaskListPresenterTest {
         }
     }
 
-    @Test
-    public void testEmptySearchString() {
-        final SearchEvent searchEvent = new SearchEvent("");
-
-        getPresenter().onSearchEvent(searchEvent);
-
-        verify(viewMock).applyFilterOnPresenter(anyString());
-        assertEquals(searchEvent.getFilter(),
-                     getPresenter().getTextSearchStr());
-    }
-
-    @Test
-    public void testSearchString() {
-        final SearchEvent searchEvent = new SearchEvent(RandomStringUtils.random(10));
-
-        getPresenter().onSearchEvent(searchEvent);
-
-        verify(viewMock).applyFilterOnPresenter(anyString());
-        assertEquals(searchEvent.getFilter(),
-                     getPresenter().getTextSearchStr());
-    }
-
-    @Test
-    public void testSearchFilterEmpty() {
-        final List<ColumnFilter> filters = getPresenter().getColumnFilters("");
-
-        assertTrue(filters.isEmpty());
-    }
-
-    @Test
-    public void testSearchFilterNull() {
-        final List<ColumnFilter> filters = getPresenter().getColumnFilters(null);
-
-        assertTrue(filters.isEmpty());
-    }
-
-    @Test
-    public void testSearchFilterEmptyTrim() {
-        final List<ColumnFilter> filters = getPresenter().getColumnFilters("     ");
-
-        assertTrue(filters.isEmpty());
-    }
-
-    @Test
-    public void testSearchFilterId() {
-        final List<ColumnFilter> filters = getPresenter().getColumnFilters("1");
-
-        assertEquals(1,
-                     filters.size());
-        assertEquals(COLUMN_TASK_ID,
-                     filters.get(0).getColumnId());
-    }
-
-    @Test
-    public void testSearchFilterIdTrim() {
-        final List<ColumnFilter> filters = getPresenter().getColumnFilters(" 1 ");
-
-        assertEquals(1,
-                     filters.size());
-        assertEquals(COLUMN_TASK_ID,
-                     filters.get(0).getColumnId());
-    }
-
-    @Test
-    public void testSearchFilterString() {
-        final List<ColumnFilter> filters = getPresenter().getColumnFilters("taskName");
-
-        assertEquals(3,
-                     filters.size());
-        assertEquals(COLUMN_NAME,
-                     filters.get(0).getColumnId());
-        assertEquals(COLUMN_DESCRIPTION,
-                     filters.get(1).getColumnId());
-        assertEquals(COLUMN_PROCESS_ID,
-                     filters.get(2).getColumnId());
-    }
-
     @Test
     public void testGetUserGroupFilters() {
         Group group1 = new Group() {
@@ -645,4 +572,43 @@ public abstract class AbstractTaskListPresenterTest {
                 COLUMN_PROCESS_INSTANCE_DESCRIPTION
         );
     }
+
+    @Test
+    public void testExitedTaskSelection() {
+        TaskSummary taskSummary = TaskSummary.builder()
+                .id(TASK_ID)
+                .deploymentId(TASK_DEPLOYMENT_ID)
+                .status(TASK_STATUS_EXITED)
+                .build();
+        boolean closed = true;
+        when(placeManager.getStatus(any(DefaultPlaceRequest.class))).thenReturn(PlaceStatus.CLOSE);
+
+        getPresenter().selectTask(taskSummary,
+                                  closed);
+
+        verify(placeManager).goTo(PerspectiveIds.TASK_DETAILS_SCREEN);
+        final ArgumentCaptor<TaskSelectionEvent> captor = ArgumentCaptor.forClass(TaskSelectionEvent.class);
+        verify(taskSelected).fire(captor.capture());
+        assertTrue(captor.getValue().isForLog());
+    }
+
+    @Test
+    public void testReadyTaskSelection() {
+        TaskSummary taskSummary = TaskSummary.builder()
+                .id(TASK_ID)
+                .deploymentId(TASK_DEPLOYMENT_ID)
+                .status(TASK_STATUS_READY)
+                .build();
+        boolean closed = true;
+        when(placeManager.getStatus(any(DefaultPlaceRequest.class))).thenReturn(PlaceStatus.CLOSE);
+
+        getPresenter().selectTask(taskSummary,
+                                  closed);
+
+        verify(placeManager).goTo(PerspectiveIds.TASK_DETAILS_SCREEN);
+        final ArgumentCaptor<TaskSelectionEvent> captor = ArgumentCaptor.forClass(TaskSelectionEvent.class);
+        verify(taskSelected).fire(captor.capture());
+        assertFalse(captor.getValue().isForLog());
+    }
+
 }
